@@ -194,4 +194,4 @@ typedef __u64	__bitwise	__be64;
 
 /* These defines are needed for the public ext2fs.h header file */
 #define HAVE_SYS_TYPES_H 1
-#undef WORDS_BIGENDIAN
+#define WORDS_BIGENDIAN 1
